@@ -5,7 +5,6 @@
 #
 
 import sys
-from string import lower as str_lower
 
 import extensions2_sup as supermod
 
@@ -108,7 +107,7 @@ supermod.simpleFactoidType.subclass = simpleFactoidTypeSub
 
 class mixedFactoidTypeSub(supermod.mixedFactoidType):
     def __init__(self, relation=None, valueOf_=None, mixedclass_=None, content_=None):
-        super(mixedFactoidTypeSub, self).__init__(valueOf_, mixedclass_, content_, )
+        super(mixedFactoidTypeSub, self).__init__(relation, valueOf_, mixedclass_, content_, )
 supermod.mixedFactoidType.subclass = mixedFactoidTypeSub
 # end class mixedFactoidTypeSub
 
@@ -168,6 +167,9 @@ def parse(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'container'
+        rootClass = supermod.containerType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
@@ -184,6 +186,9 @@ def parseString(inString):
     doc = parsexml_(StringIO(inString))
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'container'
+        rootClass = supermod.containerType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
@@ -198,6 +203,9 @@ def parseLiteral(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'container'
+        rootClass = supermod.containerType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
