@@ -5,7 +5,6 @@
 #
 
 import sys
-from string import lower as str_lower
 
 import simpletype_memberspecs2_sup as supermod
 
@@ -98,6 +97,9 @@ def parse(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'SpecialDate'
+        rootClass = supermod.SpecialDate
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
@@ -114,6 +116,9 @@ def parseString(inString):
     doc = parsexml_(StringIO(inString))
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'SpecialDate'
+        rootClass = supermod.SpecialDate
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
@@ -128,6 +133,9 @@ def parseLiteral(inFilename):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
+    if rootClass is None:
+        rootTag = 'SpecialDate'
+        rootClass = supermod.SpecialDate
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
